@@ -46,6 +46,9 @@ netrc_entry *parse_netrc __P((char *file));
 /* Return the netrc entry from LIST corresponding to HOST.  NULL is
    returned if no such entry exists. */
 netrc_entry *search_netrc __P((netrc_entry *list, char *host, char *account));
+
+/* Free the netrc list structure */
+void free_netrc __P((netrc_entry *list));
 __END_DECLS
 
 #endif /* _NETRC_H_ */
