@@ -76,64 +76,63 @@
      THERE = 292,
      TO = 293,
      MAP = 294,
-     WILDCARD = 295,
-     BATCHLIMIT = 296,
-     FETCHLIMIT = 297,
-     FETCHSIZELIMIT = 298,
-     FASTUIDL = 299,
-     EXPUNGE = 300,
-     PROPERTIES = 301,
-     SET = 302,
-     LOGFILE = 303,
-     DAEMON = 304,
-     SYSLOG = 305,
-     IDFILE = 306,
-     PIDFILE = 307,
-     INVISIBLE = 308,
-     POSTMASTER = 309,
-     BOUNCEMAIL = 310,
-     SPAMBOUNCE = 311,
-     SOFTBOUNCE = 312,
-     SHOWDOTS = 313,
-     BADHEADER = 314,
-     ACCEPT = 315,
-     REJECT_ = 316,
-     PROTO = 317,
-     AUTHTYPE = 318,
-     STRING = 319,
-     NUMBER = 320,
-     NO = 321,
-     KEEP = 322,
-     FLUSH = 323,
-     LIMITFLUSH = 324,
-     FETCHALL = 325,
-     REWRITE = 326,
-     FORCECR = 327,
-     STRIPCR = 328,
-     PASS8BITS = 329,
-     DROPSTATUS = 330,
-     DROPDELIVERED = 331,
-     DNS = 332,
-     SERVICE = 333,
-     PORT = 334,
-     UIDL = 335,
-     INTERVAL = 336,
-     MIMEDECODE = 337,
-     IDLE = 338,
-     CHECKALIAS = 339,
-     SSL = 340,
-     SSLKEY = 341,
-     SSLCERT = 342,
-     SSLPROTO = 343,
-     SSLCERTCK = 344,
-     SSLCERTFILE = 345,
-     SSLCERTPATH = 346,
-     SSLCOMMONNAME = 347,
-     SSLFINGERPRINT = 348,
-     PRINCIPAL = 349,
-     ESMTPNAME = 350,
-     ESMTPPASSWORD = 351,
-     TRACEPOLLS = 352
+     BATCHLIMIT = 295,
+     FETCHLIMIT = 296,
+     FETCHSIZELIMIT = 297,
+     FASTUIDL = 298,
+     EXPUNGE = 299,
+     PROPERTIES = 300,
+     SET = 301,
+     LOGFILE = 302,
+     DAEMON = 303,
+     SYSLOG = 304,
+     IDFILE = 305,
+     PIDFILE = 306,
+     INVISIBLE = 307,
+     POSTMASTER = 308,
+     BOUNCEMAIL = 309,
+     SPAMBOUNCE = 310,
+     SOFTBOUNCE = 311,
+     SHOWDOTS = 312,
+     BADHEADER = 313,
+     ACCEPT = 314,
+     REJECT_ = 315,
+     PROTO = 316,
+     AUTHTYPE = 317,
+     STRING = 318,
+     NUMBER = 319,
+     NO = 320,
+     KEEP = 321,
+     FLUSH = 322,
+     LIMITFLUSH = 323,
+     FETCHALL = 324,
+     REWRITE = 325,
+     FORCECR = 326,
+     STRIPCR = 327,
+     PASS8BITS = 328,
+     DROPSTATUS = 329,
+     DROPDELIVERED = 330,
+     DNS = 331,
+     SERVICE = 332,
+     PORT = 333,
+     UIDL = 334,
+     INTERVAL = 335,
+     MIMEDECODE = 336,
+     IDLE = 337,
+     CHECKALIAS = 338,
+     SSL = 339,
+     SSLKEY = 340,
+     SSLCERT = 341,
+     SSLPROTO = 342,
+     SSLCERTCK = 343,
+     SSLCERTFILE = 344,
+     SSLCERTPATH = 345,
+     SSLCOMMONNAME = 346,
+     SSLFINGERPRINT = 347,
+     PRINCIPAL = 348,
+     ESMTPNAME = 349,
+     ESMTPPASSWORD = 350,
+     TRACEPOLLS = 351
    };
 #endif
 /* Tokens.  */
@@ -174,64 +173,63 @@
 #define THERE 292
 #define TO 293
 #define MAP 294
-#define WILDCARD 295
-#define BATCHLIMIT 296
-#define FETCHLIMIT 297
-#define FETCHSIZELIMIT 298
-#define FASTUIDL 299
-#define EXPUNGE 300
-#define PROPERTIES 301
-#define SET 302
-#define LOGFILE 303
-#define DAEMON 304
-#define SYSLOG 305
-#define IDFILE 306
-#define PIDFILE 307
-#define INVISIBLE 308
-#define POSTMASTER 309
-#define BOUNCEMAIL 310
-#define SPAMBOUNCE 311
-#define SOFTBOUNCE 312
-#define SHOWDOTS 313
-#define BADHEADER 314
-#define ACCEPT 315
-#define REJECT_ 316
-#define PROTO 317
-#define AUTHTYPE 318
-#define STRING 319
-#define NUMBER 320
-#define NO 321
-#define KEEP 322
-#define FLUSH 323
-#define LIMITFLUSH 324
-#define FETCHALL 325
-#define REWRITE 326
-#define FORCECR 327
-#define STRIPCR 328
-#define PASS8BITS 329
-#define DROPSTATUS 330
-#define DROPDELIVERED 331
-#define DNS 332
-#define SERVICE 333
-#define PORT 334
-#define UIDL 335
-#define INTERVAL 336
-#define MIMEDECODE 337
-#define IDLE 338
-#define CHECKALIAS 339
-#define SSL 340
-#define SSLKEY 341
-#define SSLCERT 342
-#define SSLPROTO 343
-#define SSLCERTCK 344
-#define SSLCERTFILE 345
-#define SSLCERTPATH 346
-#define SSLCOMMONNAME 347
-#define SSLFINGERPRINT 348
-#define PRINCIPAL 349
-#define ESMTPNAME 350
-#define ESMTPPASSWORD 351
-#define TRACEPOLLS 352
+#define BATCHLIMIT 295
+#define FETCHLIMIT 296
+#define FETCHSIZELIMIT 297
+#define FASTUIDL 298
+#define EXPUNGE 299
+#define PROPERTIES 300
+#define SET 301
+#define LOGFILE 302
+#define DAEMON 303
+#define SYSLOG 304
+#define IDFILE 305
+#define PIDFILE 306
+#define INVISIBLE 307
+#define POSTMASTER 308
+#define BOUNCEMAIL 309
+#define SPAMBOUNCE 310
+#define SOFTBOUNCE 311
+#define SHOWDOTS 312
+#define BADHEADER 313
+#define ACCEPT 314
+#define REJECT_ 315
+#define PROTO 316
+#define AUTHTYPE 317
+#define STRING 318
+#define NUMBER 319
+#define NO 320
+#define KEEP 321
+#define FLUSH 322
+#define LIMITFLUSH 323
+#define FETCHALL 324
+#define REWRITE 325
+#define FORCECR 326
+#define STRIPCR 327
+#define PASS8BITS 328
+#define DROPSTATUS 329
+#define DROPDELIVERED 330
+#define DNS 331
+#define SERVICE 332
+#define PORT 333
+#define UIDL 334
+#define INTERVAL 335
+#define MIMEDECODE 336
+#define IDLE 337
+#define CHECKALIAS 338
+#define SSL 339
+#define SSLKEY 340
+#define SSLCERT 341
+#define SSLPROTO 342
+#define SSLCERTCK 343
+#define SSLCERTFILE 344
+#define SSLCERTPATH 345
+#define SSLCOMMONNAME 346
+#define SSLFINGERPRINT 347
+#define PRINCIPAL 348
+#define ESMTPNAME 349
+#define ESMTPPASSWORD 350
+#define TRACEPOLLS 351
 
 
 
@@ -250,7 +248,7 @@ typedef union YYSTYPE
 
 
 /* Line 1676 of yacc.c  */
-#line 254 "rcfile_y.h"
+#line 252 "rcfile_y.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
